@@ -28,8 +28,8 @@ use cuckoofilter::{CuckooError, CuckooFilter};
 use fnv::FnvHashSet;
 use libp2p_core::{connection::ConnectionId, PeerId};
 use libp2p_swarm::{
-    DialPeerCondition, NetworkBehaviour, NetworkBehaviourAction, NotifyHandler, OneShotHandler,
-    PollParameters,
+    dial_opts::{self, DialOpts},
+    NetworkBehaviour, NetworkBehaviourAction, NotifyHandler, OneShotHandler, PollParameters,
 };
 use log::warn;
 use smallvec::SmallVec;
@@ -107,9 +107,10 @@ impl Floodsub {
 
         if self.target_peers.insert(peer_id) {
             let handler = self.new_handler();
-            self.events.push_back(NetworkBehaviourAction::DialPeer {
-                peer_id,
-                condition: DialPeerCondition::Disconnected,
+            self.events.push_back(NetworkBehaviourAction::Dial {
+                opts: DialOpts::peer_id(peer_id)
+                    .condition(dial_opts::PeerCondition::Disconnected)
+                    .build(),
                 handler,
             });
         }
@@ -310,9 +311,10 @@ impl NetworkBehaviour for Floodsub {
         // try to reconnect.
         if self.target_peers.contains(id) {
             let handler = self.new_handler();
-            self.events.push_back(NetworkBehaviourAction::DialPeer {
-                peer_id: *id,
-                condition: DialPeerCondition::Disconnected,
+            self.events.push_back(NetworkBehaviourAction::Dial {
+                opts: DialOpts::peer_id(*id)
+                    .condition(dial_opts::PeerCondition::Disconnected)
+                    .build(),
                 handler,
             });
         }
